@@ -4,6 +4,14 @@ import html
 from typing import Optional, Collection, Sequence
 
 import numpy as np
+import pandas as pd
+
+def _rescale(data, min_, max_):
+  # Handle nan values
+  rng = (max_ - min_)
+  if rng == 0:
+    return np.ones_like(data)
+  return (data.astype(float) - min_)/rng
 
 _specialKeys = ['name', 'value', 'helpText', 'pType']
 class _UNSPECIFIED_DEFAULT: pass
@@ -33,10 +41,13 @@ class PrjParam:
     ht = helpText or opts.get('tip', None)
     if ht:
       # TODO: Checking for mightBeRichText fails on pyside2? Even though the function
-      # is supposed to exist?
-      ht = html.escape(ht)
-      # Makes sure the label is displayed as rich text
-      helpText = f'<qt>{ht}</qt>'
+      #   is supposed to exist?
+      if not ht.startswith('<qt>'):
+        ht = html.escape(ht)
+        # Makes sure the label is displayed as rich text
+        helpText = f'<qt>{ht}</qt>'
+      else:
+        helpText = ht
     self.name = name
     self.value = value
     self.pType = pType
@@ -91,7 +102,8 @@ class PrjParam:
     # sufficient to form a proper hash
     return hash(self.name,)
 
-  def toNumeric(self, data: Sequence, offset:bool=None, rescale=False, returnUnique=False):
+  def toNumeric(self, data: Sequence, offset:bool=None, rescale=False,
+                returnMapping=False):
     """
     Useful for converting string-like or list-like parameters to integer representations.
     If self's `value` is non-numeric data (e.g. strings):
@@ -108,11 +120,14 @@ class PrjParam:
       will be applied. Otherwise, `offset` will be *True*.
     :param rescale: If *True*, values will be rescaled to the range 0-1. `offset` is ignored
       in that case.
-    :param returnUnique: Whether to also return an array of the unique values within `data`.
+    :param returnMapping: Whether to also return an array of the unique values within `data`.
       If data is already numeric, *None* is returned instead of this array.
    """
     numericVals = np.asarray(data).copy()
-    if numericVals.size == 0:
+    if len(data) == 0:
+      mapping = pd.Series(name=self, dtype=object)
+      if returnMapping:
+        return numericVals, mapping
       return numericVals
     if not np.issubdtype(type(self.value), np.number):
       if offset is None:
@@ -122,19 +137,32 @@ class PrjParam:
       if 'limits' in self.opts:
         listLims = list(self.opts['limits'])
         numericVals = np.array([listLims.index(v) for v in numericVals])
+        mapping = pd.Series(listLims, np.arange(len(listLims), dtype=int))
       else:
-        listLims, numericVals = np.unique(numericVals, return_inverse=True)
+        listLims, numericIdxs, numericVals = np.unique(numericVals,
+                                                       return_index=True,
+                                                       return_inverse=True)
+        mapping = pd.Series(listLims, numericVals[numericIdxs], name=self)
+    elif returnMapping:
+      # Potentially expensive, only compute if requested
+      uniques = np.unique(numericVals)
+      mapping = pd.Series(uniques, uniques, name=self)
     else:
-      listLims = None
-    if offset and not rescale:
+      # Dummy mapping to allow ops
+      class mapping:
+        index = np.array([numericVals.max(), numericVals.min()])
+    if offset:
       numericVals += 1
+      mapping.index += 1
     if rescale:
-      maxVal = len(listLims) if listLims is not None else np.max(data)
-      if maxVal > 0:
-        # Can't use /= since dtype may change
-        numericVals =  numericVals / maxVal
-    if returnUnique:
-      return numericVals, listLims
+      min_, max_ = mapping.index.min(), mapping.index.max()
+      if offset:
+        # Make sure to reduce min to account for this
+        min_ -= 1
+      numericVals = _rescale(numericVals, min_, max_)
+      mapping.index = _rescale(mapping.index, min_, max_)
+    if returnMapping:
+      return numericVals, mapping
     return numericVals
 
   def __getitem__(self, item):
