@@ -5,6 +5,7 @@ from functools import wraps
 from typing import List, Sequence, Callable, Union
 
 from pyqtgraph.parametertree import Parameter
+from pyqtgraph.parametertree.Parameter import PARAM_TYPES
 from pyqtgraph.parametertree.parameterTypes import GroupParameter
 
 from .prjparam import PrjParam
@@ -52,7 +53,7 @@ def addStageToParam(stage: ProcessStage, parentParam: Parameter, **kwargs):
 @addStageToParam.register
 def addAtomicToParam(stage: AtomicProcess, parentParam: Parameter,
                      argNameFormat: Callable[[str], str]=None, nestHyperparams=True, **kwargs):
-  docParams = fns.docParser(stage.func.__doc__)
+  docParams = fns.docParser(stage.fnDoc)
   if nestHyperparams:
     parentParam = fns.getParamChild(parentParam, chOpts=_mkProcParam(stage))
   if docParams['top-descr']:
@@ -68,6 +69,8 @@ def addAtomicToParam(stage: AtomicProcess, parentParam: Parameter,
       if curParam.pType is None:
         curParam.pType = type(val).__name__
     paramDict = curParam.toPgDict()
+    if paramDict['type'] not in PARAM_TYPES:
+      continue
     if argNameFormat is not None and 'title' not in paramDict:
       paramDict['title'] = argNameFormat(key)
     pgParam = fns.getParamChild(parentParam, chOpts=paramDict)
