@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 import typing as t
 from textwrap import wrap
 from warnings import warn
@@ -1126,4 +1127,13 @@ class DummySignal:
   """Useful for spoofing a qt connection that doesn't do anything"""
   def connect(self, *args): pass
   def disconnect(self, *args): pass
-  def emit(self, *args): pass
\ No newline at end of file
+  def emit(self, *args): pass
+
+@contextlib.contextmanager
+def makeDummySignal(obj, sigName: str):
+  oldSig = getattr(obj, sigName)
+  try:
+    setattr(obj, sigName, DummySignal())
+    yield
+  finally:
+    setattr(obj, sigName, oldSig)
\ No newline at end of file
